@@ -149,7 +149,12 @@ static char *ssl_ext_mlc_function_c(request_rec *r, char *a)
  */
 static char *ssl_ext_mlc_function_x(request_rec *r, char *a)
 {
-    return ssl_var_lookup(r->pool, r->server, r->connection, r, a);
+    char *result;
+
+    result = NULL;
+    if (ap_ctx_get(r->connection->client->ctx, "ssl") != NULL)
+        result = ssl_var_lookup(r->pool, r->server, r->connection, r, a);
+    return result;
 }
 
 
