@@ -246,37 +246,29 @@ void ssl_init_Module(server_rec *s, pool *p)
     for (; s != NULL; s = s->next) {
         sc = mySrvConfig(s);
 
-        if (sc->bEnabled)
-            ssl_log(s, SSL_LOG_INFO,
-                    "Init: Configuring server %s:%d for SSL protocol",
-                    s->server_hostname, s->port);
-
-        /* If we are disabled skip this server but
-           make sure the port is initialized correctly */
-        if (!sc->bEnabled) {
-            if (!s->port)
-                s->port = DEFAULT_HTTP_PORT;
-            continue;
-        }
-
-        /* Give a warning when HTTPS is configured for HTTP port */
-        if (s->port == DEFAULT_HTTP_PORT)
-            ssl_log(s, SSL_LOG_WARN,
-                    "Init: You configured HTTPS on the standard HTTP(%d) port!",
-                    DEFAULT_HTTP_PORT);
-        if (!s->port)
-            s->port = DEFAULT_HTTPS_PORT;
-
-        /*
-         * Now check for important parameters and the
-         * possibility that the user forgot to set them.
+        /* 
+         * Give out warnings when HTTPS is configured for
+         * the HTTP port or vice versa
          */
-        if (sc->szCertificateFile == NULL) {
-            ssl_log(s, SSL_LOG_ERROR,
-                    "Init: (%s:%d) No SSL Certificate set [hint: SSLCertificateFile]",
-                    s->server_hostname, s->port);
-            ssl_die();
-        }
+        if (sc->bEnabled && s->port == DEFAULT_HTTP_PORT)
+            ssl_log(s, SSL_LOG_WARN,
+                    "Init: You configured HTTPS(%d) on the standard HTTP(%d) port!",
+                    DEFAULT_HTTPS_PORT, DEFAULT_HTTP_PORT);
+        if (!sc->bEnabled && s->port == DEFAULT_HTTPS_PORT)
+            ssl_log(s, SSL_LOG_WARN,
+                    "Init: You configured HTTP(%d) on the standard HTTPS(%d) port!",
+                    DEFAULT_HTTP_PORT, DEFAULT_HTTPS_PORT);
+
+        /* 
+         * Either now skip this server when SSL is disabled for
+         * it or give out some information about what we're
+         * configuring.
+         */
+        if (!sc->bEnabled)
+            continue;
+        ssl_log(s, SSL_LOG_INFO,
+                "Init: Configuring server %s for SSL protocol",
+                ssl_util_vhostid(p, s));
 
         /*
          * Read the server certificate and key
@@ -318,34 +310,48 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
 {
     SSLModConfigRec *mc = myModConfig();
     int nVerify;
-    char *cpServerName;
+    char *cpVHostID;
     RSA **ppRSA;
     X509 **ppX509;
     SSL_CTX *ctx;
 
-    cpServerName = ap_psprintf(p, "%s:%d", s->server_hostname, s->port);
+    /*
+     * Create the server host:port string because we need it a lot
+     */
+    cpVHostID = ssl_util_vhostid(p, s);
+
+    /*
+     * Now check for important parameters and the
+     * possibility that the user forgot to set them.
+     */
+    if (sc->szCertificateFile == NULL) {
+        ssl_log(s, SSL_LOG_ERROR,
+                "Init: (%s) No SSL Certificate set [hint: SSLCertificateFile]",
+                cpVHostID);
+        ssl_die();
+    }
 
     /*
      *  Check for problematic re-initializations
      */
     if (sc->px509Certificate) {
         ssl_log(s, SSL_LOG_ERROR,
-                "Init: (%s) Illegal attempt to re-initialise SSL for server",
-                cpServerName);
+                "Init: (%s) Illegal attempt to re-initialise SSL for server "
+                "(theoretically shouldn't happen!)", cpVHostID);
         ssl_die();
     }
 
     /*
-     *  Create new SSL context
+     *  Create the new per-server SSL context
      */
     ssl_log(s, SSL_LOG_TRACE,
-            "Init: (%s) Creating new SSL context", cpServerName);
+            "Init: (%s) Creating new SSL context", cpVHostID);
     ctx = SSL_CTX_new(SSLv23_server_method());
     SSL_CTX_set_app_data(ctx, s);
     sc->pSSLCtx = ctx;
 
     /*
-     *  Configure callback for SSL context
+     *  Configure callbacks for SSL context
      */
     nVerify = SSL_VERIFY_NONE;
     if (sc->nVerifyClient == SSL_CVERIFY_REQUIRE)
@@ -361,15 +367,15 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
     SSL_CTX_set_info_callback(ctx,    ssl_callback_LogTracingState);
 
     /*
-     *  Configure required SSL Ciphers
+     *  Configure SSL Cipher Suite
      */
     ssl_log(s, SSL_LOG_TRACE,
-            "Init: (%s) Configuring permitted SSL ciphers", cpServerName);
+            "Init: (%s) Configuring permitted SSL ciphers", cpVHostID);
     if (sc->szCipherSuite != NULL) {
         if (!SSL_CTX_set_cipher_list(sc->pSSLCtx, sc->szCipherSuite)) {
             ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Init: (%s) Unable to configure permitted SSL ciphers",
-                    cpServerName);
+                    cpVHostID);
             ssl_die();
         }
     }
@@ -380,19 +386,19 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
     if (sc->szCACertificateFile != NULL || sc->szCACertificatePath != NULL) {
         STACK *skCAList;
         ssl_log(s, SSL_LOG_TRACE,
-                "Init: (%s) Configuring client authentication", cpServerName);
+                "Init: (%s) Configuring client authentication", cpVHostID);
         if (!SSL_CTX_load_verify_locations(sc->pSSLCtx,
                 sc->szCACertificateFile, sc->szCACertificatePath)) {
             ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Init: (%s) Unable to configure verify locations "
-                    "for client authentication", cpServerName);
+                    "for client authentication", cpVHostID);
             ssl_die();
         }
         if ((skCAList = ssl_init_FindCAList(s, p, sc->szCACertificateFile,
                                             sc->szCACertificatePath)) == NULL) {
             ssl_log(s, SSL_LOG_ERROR,
                     "Init: (%s) Unable to determine list of available "
-                    "CA certificates for client authentication", cpServerName);
+                    "CA certificates for client authentication", cpVHostID);
             ssl_die();
         }
         SSL_CTX_set_client_CA_list(sc->pSSLCtx, skCAList);
@@ -402,11 +408,11 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
      *  Configure server certificate
      */
     ssl_log(s, SSL_LOG_TRACE,
-            "Init: (%s) Configuring server certificate", cpServerName);
+            "Init: (%s) Configuring server certificate", cpVHostID);
     if ((ppX509 = (X509 **)ssl_ds_table_get(mc->tPublicCert,
-                                            cpServerName)) == NULL) {
+                                            cpVHostID)) == NULL) {
         ssl_log(s, SSL_LOG_ERROR,
-                "Init: (%s) Ops, can't find server certificate?!", cpServerName);
+                "Init: (%s) Ops, can't find server certificate?!", cpVHostID);
         ssl_die();
     }
     sc->px509Certificate = *ppX509;
@@ -415,10 +421,10 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
      *  Configure server private key
      */
     ssl_log(s, SSL_LOG_TRACE,
-            "Init: (%s) Configuring server private key", cpServerName);
-    if ((ppRSA = (RSA **)ssl_ds_table_get(mc->tPrivateKey, cpServerName)) == NULL) {
+            "Init: (%s) Configuring server private key", cpVHostID);
+    if ((ppRSA = (RSA **)ssl_ds_table_get(mc->tPrivateKey, cpVHostID)) == NULL) {
         ssl_log(s, SSL_LOG_ERROR,
-                "Init: (%s) Ops, can't find server private key?!", cpServerName);
+                "Init: (%s) Ops, can't find server private key?!", cpVHostID);
         ssl_die();
     }
     sc->prsaKey = *ppRSA;
