@@ -395,7 +395,7 @@ static void ssl_io_data_dump(server_rec *srvr, char *s, long len)
     }
     if (trunc > 0)
         ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID,
-                "%04x - <SPACES/NULS>", len + trunc);
+                "| %04x - <SPACES/NULS>", len + trunc);
     ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID,
             "+-------------------------------------------------------------------------+");
     return;
@@ -413,17 +413,21 @@ long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long len
         return len;
     s = c->server;
 
-    if (cmd == (BIO_CB_READ|BIO_CB_RETURN)) {
+    if (len >= 0) {
         ssl_log(s, SSL_LOG_DEBUG,
-                "%s: read %ld/%d bytes from BIO#%08X [mem: %08lX] (BIO dump follows)",
-                SSL_LIBRARY_NAME, len, argi, bio, argp);
-        ssl_io_data_dump(s, argp, len);
+                "%s: %s %ld/%d bytes %s BIO#%08X [mem: %08lX] %s",
+                SSL_LIBRARY_NAME, (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
+                len, argi, (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "to" : "from"),
+                bio, argp, (argp != NULL ? "(BIO dump follows)" : "(Ops, no memory buffer?)"));
+        if (argp != NULL)
+            ssl_io_data_dump(s, argp, len);
     }
-    else if (cmd == (BIO_CB_WRITE|BIO_CB_RETURN)) {
+    else {
         ssl_log(s, SSL_LOG_DEBUG,
-                "%s: write %ld/%d bytes to BIO#%08X [mem: %08lX] (BIO dump follows)",
-                SSL_LIBRARY_NAME, len, argi, bio, argp);
-        ssl_io_data_dump(s, argp, len);
+                "%s: I/O error, %d bytes expected to %s on BIO#%08X [mem: %08lX]",
+                SSL_LIBRARY_NAME, argi, 
+                (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
+                bio, argp);
     }
     return len;
 }
