@@ -318,7 +318,8 @@ void ssl_hook_NewConnection(conn_rec *conn)
                  * Ok, anything else is a fatal error
                  */
                 ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLERR|SSL_ADD_ERRNO,
-                        "SSL handshake failed");
+                        "SSL handshake failed (client %s, server %s)",
+                        conn->remote_ip, ssl_util_vhostid(conn->pool, srvr));
 
                 /*
                  * try to gracefully shutdown the connection:
@@ -480,14 +481,13 @@ int ssl_hook_Handler(request_rec *r)
                               ap_get_server_name(r), thisport);
 
         ap_table_setn(r->notes, "error-notes", ap_psprintf(r->pool,
-                      "Reason: You're speaking plain HTTP to an SSL-enabled server.<BR>\n"
-                      "Instead use the HTTPS protocol to access this server, please.<BR>\n"
+                      "Reason: You're speaking plain HTTP to an SSL-enabled server port.<BR>\n"
+                      "Instead use the HTTPS scheme to access this URL, please.<BR>\n"
                       "<BLOCKQUOTE>Hint: <A HREF=\"%s\"><B>%s</B></A></BLOCKQUOTE>",
                       thisurl, thisurl));
-        r->status_line = "500 SSL Engine Error";
     }
 
-    return HTTP_INTERNAL_SERVER_ERROR;
+    return HTTP_BAD_REQUEST;
 }
 
 /*
