@@ -173,6 +173,12 @@ void ssl_log(server_rec *s, int level, const char *msg, ...)
     add   = (level & ~SSL_LOG_MASK);
     level = (level & SSL_LOG_MASK);
 
+    /*  reduce flags when not reasonable in context  */
+    if (add & SSL_ADD_ERRNO && errno == 0)
+        add &= ~SSL_ADD_ERRNO;
+    if (add & SSL_ADD_SSLERR && ERR_peek_error() == 0)
+        add &= ~SSL_ADD_SSLERR;
+
     /*  we log only levels below, except for errors */
     if (   sc->fileLogFile == NULL
         && !(level & SSL_LOG_ERROR))
